import importlib

def isoformat(dt):
    """ Formats a datetime object to an ISO string. Timezone naive datetimes are
        are treated as UTC Zulu. UTC Zulu is expressed with the proper "Z"
        ending and not with the "+00:00" offset declaration.

        :param dt: the :class:`datetime.datetime` to encode
        :returns: an encoded string
    """
    if not dt.utcoffset():
        dt = dt.replace(tzinfo=None)
        return dt.isoformat("T") + "Z"
    return dt.isoformat("T")


def import_by_path(path: str):
    """ Imports the object from the referenced module.

        :param path: the dotted Python path, where the last element is the
                     object in the referenced module.
    """
    module_path, _, object_name = path.rpartition('.')
    return getattr(importlib.import_module(module_path), object_name)
