# ------------------------------------------------------------------------------
#
# Project: prism view server
# Authors: Fabian Schindler <fabian.schindler@eox.at>
#
# ------------------------------------------------------------------------------
# Copyright (C) 2020 EOX IT Services GmbH <https://eox.at>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies of this Software or works derived from this Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
# -----------------------------------------------------------------------------

import os
import shutil
from datetime import datetime


def pairwise(iterable):
    "s -> (s0,s1), (s2,s3), (s4, s5), ..."
    a = iter(iterable)
    return zip(a, a)


def converter(o):
    if isinstance(o, datetime):
        return o.isoformat()


def save_mount_report(data, success: bool):
    if success:
        save_dir = os.environ['INGESTOR_SUCCESS_DIR']
    else:
        save_dir = os.environ['INGESTOR_FAIL_DIR']

    shutil.copy(data, save_dir)
    os.remove(data)


def save_endpoint_report(filename: str, data, success: bool):
    if success:
        save_dir = os.environ['INGESTOR_SUCCESS_DIR']
    else:
        save_dir = os.environ['INGESTOR_FAIL_DIR']

    with open(os.path.join(save_dir, '%s.xml' % filename), "w") as outfile:
        outfile.write(data)


def browse_name(report):
    return '_'.join(browse["browse_identifier"] for browse in report["browses"])
